#include <stdio.h>
#include <stdlib.h>
#include <GL/gl.h>
#include "ex.h"

void redraw(void);
void reshape(int x, int y);
void keyb(unsigned int key, int press);
void mouse(int bn, int press, int x, int y);
void motion(int x, int y);

float curs_x, curs_y;

int main(void)
{
	if(create_gfx(800, 600, 0) == -1) {
		return 1;
	}

	display_func(redraw);
	keyboard_func(keyb);
	mouse_func(mouse);
	motion_func(motion);

	glClearColor(0, 0, 0, 0);
	glClearDepth(1.0);

	/* blocking main loop */
	do {
		wait_event();
	} while(process_events());

	/* busy main loop */
	/*
	while(process_events()) {
	}
	*/

	destroy_gfx();
	return 0;
}

void redraw(void)
{
	glClear(GL_COLOR_BUFFER_BIT);

	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();
	glTranslatef(curs_x, curs_y, 0);

	glBegin(GL_TRIANGLES);
	glColor3f(0.8, 0.1, 0.05);
	glVertex2f(0, 0);
	glVertex2f(0.08, -0.08);
	glVertex2f(0.025, -0.07);
	glVertex2f(0, 0);
	glVertex2f(0.025, -0.07);
	glVertex2f(0, -0.15);
	glEnd();

	swap_buffers();
}

void reshape(int x, int y)
{
	glViewport(0, 0, x, y);
}

void keyb(unsigned int key, int press)
{
	if(press && key == 27) {
		destroy_gfx();
		exit(0);
	}
}

void mouse(int bn, int press, int x, int y)
{
	static float val;

	if(bn == 1 && !press) {
		val = val > 0.5 ? 0.0 : 1.0;

		glClearColor(val, val, val, 0);
		post_redisplay();
	}
}

void motion(int x, int y)
{
	curs_x = 2.0 * (x / 800.0) - 1.0;
	curs_y = 1.0 - 2.0 * (y / 600.0);
	post_redisplay();
}
